import path from 'node:path';
import { globSync } from 'glob';
import { BaseWorkspaceScanner } from './scanner.js';
/**
 * This scanner will accept paths and builds a list of module ids to component paths.
 */
export default class InternalWorkspaceScanner extends BaseWorkspaceScanner {
    findModuleDirs() {
        let lwcDirs = this.modulesPaths.flatMap((uimodule) => globSync(`${uimodule}/**/modules/*/*/`));
        const jsMetaXmls = this.modulesPaths.flatMap((uimodule) => globSync(`${uimodule}/**/modules/*/*/**/*.js-meta.xml`));
        lwcDirs = lwcDirs.concat(jsMetaXmls.map((jsMetaXml) => path.dirname(jsMetaXml)));
        if (this.excludePaths) {
            lwcDirs = lwcDirs.filter((dir) => !this.excludePaths.includes(dir));
        }
        return Array.from(new Set(lwcDirs));
    }
    getNamespace(moduleDir) {
        const namespaceBegin = moduleDir.indexOf('/modules/') + '/modules/'.length;
        const namespaceEnd = moduleDir.indexOf('/', namespaceBegin);
        return moduleDir.substring(namespaceBegin, namespaceEnd);
    }
}
//# sourceMappingURL=internal.js.map